# Getting Started

## Requirements

* Python 3.3+

## Installation

Grortir can be installed with pip:

```
$ pip install grortir
```

or directly from the source code:

```
$ git clone https://github.com/qbahn/grortir.git
$ cd grortir
$ python setup.py install
```

## Basic Usage

After installation, the package can imported:

```
$ python
>>> import grortir
>>> grortir.__version__
```

## Documentation

Read the full documentation:
 
### [http://qbahn.github.io/grortir](http://qbahn.github.io/grortir)

## For contributors
Check file:
[docs/about/contributing.md](about/contributing.md)